::: py_ballisticcalc_exts.CythonizedBaseTrajData
    options:
        show_docstring_examples: false
        members: false
        show_docstring_attributes: false
        docstring_section_style: list

::: py_ballisticcalc_exts.CythonizedBaseTrajSeq
    options:
        show_docstring_examples: false
        members: false
        show_docstring_attributes: false
        docstring_section_style: list

::: py_ballisticcalc_exts.CythonizedBaseIntegrationEngine
    options:
        show_docstring_examples: false
        members: false
        show_docstring_attributes: false
        docstring_section_style: list

::: py_ballisticcalc_exts.CythonizedRK4IntegrationEngine
    options:
        show_docstring_examples: false
        members: false
        show_docstring_attributes: false
        docstring_section_style: list

::: py_ballisticcalc_exts.CythonizedEulerIntegrationEngine
    options:
        show_docstring_examples: false
        members: false
        show_docstring_attributes: false
        docstring_section_style: list
